@@ -882,10 +882,6 @@ int setup_configfs_options(void)
 	    dlm_options[log_debug_ind].file_set)
 		set_configfs_cluster("log_debug", NULL, opt(log_debug_ind));
 
-	if (dlm_options[timewarn_ind].cli_set ||
-	    dlm_options[timewarn_ind].file_set)
-		set_configfs_cluster("timewarn_cs", NULL, opt(timewarn_ind));
-
 	if (dlm_options[port_ind].cli_set ||
 	    dlm_options[port_ind].file_set)
 		set_configfs_cluster("tcp_port", NULL, optu(port_ind));
