@@ -102,7 +102,6 @@ enum {
         daemon_debug_ind = 0,
         foreground_ind,
         log_debug_ind,
-        timewarn_ind,
         protocol_ind,
         port_ind,
         debug_logfile_ind,
@@ -414,6 +413,7 @@ int set_lockspaces(int *count, struct dlmc_lockspace **lss_out);
 int set_lockspace_nodes(struct lockspace *ls, int option, int *node_count,
 			struct dlmc_node **nodes_out);
 int set_fs_notified(struct lockspace *ls, int nodeid);
+void cpg_stop_kernel(struct lockspace *ls);
 
 /* daemon_cpg.c */
 void init_daemon(void);
