@@ -10,6 +10,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdint.h>
+#include <string.h>
 #include <errno.h>
 #include <time.h>
 #include <sys/types.h>
@@ -667,24 +668,11 @@ int dlmc_lockspace_info(char *name, struct dlmc_lockspace *lockspace)
 	return rv;
 }
 
-int dlmc_lockspaces(int max, int *count, struct dlmc_lockspace *lss)
+int dlmc_lockspaces(int *count, struct dlmc_lockspace **lss)
 {
-	struct dlmc_header h, *rh;
-	char *reply;
+	struct dlmc_header h;
 	int reply_len;
-	int fd, rv, result, ls_count;
-
-	init_header(&h, DLMC_CMD_LOCKSPACES, NULL, 0);
-	h.data = max;
-
-	reply_len = sizeof(struct dlmc_header) +
-		    (max * sizeof(struct dlmc_lockspace));
-	reply = malloc(reply_len);
-	if (!reply) {
-		rv = -1;
-		goto out;
-	}
-	memset(reply, 0, reply_len);
+	int fd, rv, result;
 
 	fd = do_connect(DLMC_QUERY_SOCK_PATH);
 	if (fd < 0) {
@@ -692,31 +680,40 @@ int dlmc_lockspaces(int max, int *count, struct dlmc_lockspace *lss)
 		goto out;
 	}
 
+	init_header(&h, DLMC_CMD_LOCKSPACES, NULL, 0);
+
 	rv = do_write(fd, &h, sizeof(h));
 	if (rv < 0)
 		goto out_close;
 
-	/* won't usually get back the full reply_len */
-	do_read(fd, reply, reply_len);
+	rv = do_read(fd, &h, sizeof(h));
+	if (rv <0)
+		goto out_close;
 
-	rh = (struct dlmc_header *)reply;
-	result = rh->data;
-	if (result < 0 && result != -E2BIG) {
+	result = h.data;
+	if (result < 0) {
 		rv = result;
 		goto out_close;
 	}
 
-	if (result == -E2BIG) {
-		*count = -E2BIG;
-		ls_count = max;
-	} else {
-		*count = result;
-		ls_count = result;
+	*count = result;
+
+	reply_len = h.len - sizeof(struct dlmc_header);
+	*lss = malloc(reply_len);
+	if (!*lss) {
+		rv = -1;
+		goto out;
 	}
+	memset(*lss, 0, reply_len);
+
+	rv = do_read(fd, *lss, reply_len);
+	if (rv < 0) {
+		free(*lss);
+		goto out;
+	}
+
 	rv = 0;
 
-	memcpy(lss, (char *)reply + sizeof(struct dlmc_header),
-	       ls_count * sizeof(struct dlmc_lockspace));
  out_close:
 	close(fd);
  out:
