@@ -1070,7 +1070,7 @@ static void query_node_info(int fd, char *name, int nodeid)
 		 (char *)&node, sizeof(node));
 }
 
-static void query_lockspaces(int fd, int max)
+static void query_lockspaces(int fd)
 {
 	int ls_count = 0;
 	struct dlmc_lockspace *lss = NULL;
@@ -1083,12 +1083,7 @@ static void query_lockspaces(int fd, int max)
 		goto out;
 	}
 
-	if (ls_count > max) {
-		result = -E2BIG;
-		ls_count = max;
-	} else {
-		result = ls_count;
-	}
+	result = ls_count;
  out:
 	do_reply(fd, DLMC_CMD_LOCKSPACES, NULL, result, 0,
 		 (char *)lss, ls_count * sizeof(struct dlmc_lockspace));
@@ -1375,7 +1370,7 @@ static void *process_queries(void *arg)
 			query_node_info(f, h.name, h.data);
 			break;
 		case DLMC_CMD_LOCKSPACES:
-			query_lockspaces(f, h.data);
+			query_lockspaces(f);
 			break;
 		case DLMC_CMD_LOCKSPACE_NODES:
 			query_lockspace_nodes(f, h.name, h.option, h.data);
@@ -1609,12 +1604,14 @@ static int loop(void)
 	close_plocks();
 	close_cpg_daemon();
 	clear_configfs();
-	close_logging();
 	close_cluster();
 	close_cluster_cfg();
 
 	list_for_each_entry(ls, &lockspaces, list)
 		log_error("abandoned lockspace %s", ls->name);
+
+	/* must be end */
+	close_logging();
 	return rv;
 }
 
@@ -1801,11 +1798,6 @@ static void set_opt_defaults(void)
 			0, NULL, 0, 1,
 			"enable kernel dlm debugging messages");
 
-	set_opt_default(timewarn_ind,
-			"timewarn", '\0', req_arg_int,
-			0, NULL, 0, 0,
-			""); /* do not advertise */
-
 	set_opt_default(protocol_ind,
 			"protocol", 'r', req_arg_str,
 			-1, "detect", 0, 0,
