@@ -67,7 +67,6 @@ static int summarize;
 char run_command[DLMC_RUN_COMMAND_LEN];
 char run_uuid[DLMC_RUN_UUID_LEN];
 
-#define MAX_LS 128
 #define MAX_NODES 128
 
 /* from linux/fs/dlm/dlm_internal.h */
@@ -91,7 +90,6 @@ char run_uuid[DLMC_RUN_UUID_LEN];
 #define DLM_MSG_PURGE           14
 
 
-struct dlmc_lockspace lss[MAX_LS];
 struct dlmc_node nodes[MAX_NODES];
 
 struct rinfo {
@@ -1404,19 +1402,23 @@ static void show_all_nodes(int count, struct dlmc_node *nodes_in)
 
 static void do_list(char *name)
 {
+	struct dlmc_lockspace *lss;
 	struct dlmc_lockspace *ls;
 	int node_count;
 	int ls_count;
 	int rv;
 	int i;
 
-	memset(lss, 0, sizeof(lss));
-
 	if (name) {
+		/* get only one specific lockspace by name */
 		ls_count = 1;
+		lss = malloc(sizeof(struct dlmc_lockspace));
+		if (!lss)
+			exit(EXIT_FAILURE);
+
 		rv = dlmc_lockspace_info(name, lss);
 	} else {
-		rv = dlmc_lockspaces(MAX_LS, &ls_count, lss);
+		rv = dlmc_lockspaces(&ls_count, &lss);
 	}
 
 	if (rv < 0)
@@ -1450,6 +1452,8 @@ static void do_list(char *name)
  next:
 		printf("\n");
 	}
+
+	free(lss);
 }
 
 static void do_deadlock_check(char *name)
